Do not have any default credentials set on the application. Any known usernames
or passwords associated with the application framework should also be removed.
Furthermore, Web Applications should implement a strong password policy consisting
of a combination of alphanumeric characters and a minimum length of 8 characters.